from .mercadopago_sdk.MercadoPagoSDK import MercadoPagoSDK
from .decidir_sdk.DecidirSDK import DecidirSDK


class SDK:
    def __init__(self, merchant:dict,processor:str=None):
        # Si se le indica el procesador
        self.processor = None
        if processor == 'mercadopago':
            self._sdk = MercadoPagoSDK(merchant)
            self.processor == processor
            return
        elif processor == 'decidir':
            self._sdk = DecidirSDK(merchant)
            self.processor == processor
            return
        # Si no utiliza el preferrred_processor que tenga el merchant
        if 'credentials' in merchant and merchant['credentials']['preferred_processor'] == 'decidir':
            self._sdk = DecidirSDK(merchant)
            self.processor == 'decidir'
        else:
            self._sdk = MercadoPagoSDK(merchant)
            self.processor == 'mercadopago'

    def customer(self):
        return self._sdk.customer()

    def card(self):
        return self._sdk.card()

    def card_token(self):
        return self._sdk.card_token()

    def payment(self):
        return self._sdk.payment()

    def which(self):
        return self.processor 



import requests
import json
from uuid import uuid4

from ..response import ok, error


class Payment:
    def __init__(self, url, private_key: str, public_key: str):
        self.url = url
        self.private_key = private_key
        self.public_key = public_key
        self.headers = {
            'apikey': self.private_key,
            'Content-Type': 'application/json',
            'Cache-Control': 'no-cache'
        }

    def create(self, payment_data: dict):
        body = {
            'customer': {
                'id': payment_data['payer']['decidir_id'],
                'email': payment_data['payer']['email']
            },
            'site_transaction_id': str(uuid4()),  # Debe ser unico? Unico por cliente o por merchant?
            # 'site_id': 28464385, # opcional
            'token': payment_data['token'],
            'payment_method_id': 1,    # Peso Argentino
            'bin': '450799',    # ?
            # se multiplica por 100; no acepta decimales.
            'amount': round(payment_data['transaction_amount'], 2) * 100,
            'currency': 'ARS',
            'installments': 1,
            'payment_type': 'single',
            'establishment_name': 'Cadena',  # opcional
            'sub_payments': []
        }
        r = requests.post(self.url + '/payments', headers=self.headers, data=json.dumps(body))
        response = r.json()
        response['processor'] = 'decidir'
        if r.status_code < 400:
            response['status_detail'] = 'ok decidir'
            return ok(response)
        return error(response)

    def get(self, payment_id: int):
        r = requests.get(self.url + '/payments/{}'.format(payment_id), headers=self.headers)
        return ok(r.json())
